==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/mixins/entity/DamageSourcesMixin.java <==
package com.github.thedeathlycow.frostiful.mixins.entity;

import com.github.thedeathlycow.frostiful.entity.damage.FDamageSources;
import com.github.thedeathlycow.frostiful.entity.damage.FDamageTypes;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_5321;
import net.minecraft.class_5455;
import net.minecraft.class_8109;
import net.minecraft.class_8110;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_8109.class)
public abstract class DamageSourcesMixin implements FDamageSources {

    @Shadow
    protected abstract class_1282 source(class_5321<class_8110> key, @Nullable class_1297 attacker);

    @Shadow
    protected abstract class_1282 source(class_5321<class_8110> key);

    @Unique
    private class_1282 frostiful$icicle;

    @Inject(
            method = "<init>",
            at = @At("TAIL")
    )
    private void init(class_5455 registryManager, CallbackInfo ci) {
        this.frostiful$icicle = this.source(FDamageTypes.ICICLE);
    }

    @Override
    @Unique
    public class_1282 frostiful$fallingIcicle(class_1297 attacker) {
        return this.source(FDamageTypes.FALLING_ICICLE, attacker);
    }

    @Override
    @Unique
    public class_1282 frostiful$icicle() {
        return this.frostiful$icicle;
    }

    @Override
    @Unique
    public class_1282 frostiful$iceSkate(class_1297 attacker) {
        return this.source(FDamageTypes.ICE_SKATE, attacker);
    }

    @Override
    @Unique
    public class_1282 frostiful$brokenIce(class_1297 attacker) {
        return this.source(FDamageTypes.BROKEN_ICE, attacker);
    }
}

==> frostiful-2.2.9%2B1.21.9-sources.jar: com/github/thedeathlycow/frostiful/mixins/entity/DamageSourcesMixin.java <==
package com.github.thedeathlycow.frostiful.mixins.entity;

import com.github.thedeathlycow.frostiful.entity.damage.FDamageSources;
import com.github.thedeathlycow.frostiful.entity.damage.FDamageTypes;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_5321;
import net.minecraft.class_5455;
import net.minecraft.class_8109;
import net.minecraft.class_8110;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_8109.class)
public abstract class DamageSourcesMixin implements FDamageSources {

    @Shadow
    protected abstract class_1282 create(class_5321<class_8110> key, @Nullable class_1297 attacker);

    @Shadow
    protected abstract class_1282 create(class_5321<class_8110> key);

    @Unique
    private class_1282 frostiful$icicle;

    @Inject(
            method = "<init>",
            at = @At("TAIL")
    )
    private void init(class_5455 registryManager, CallbackInfo ci) {
        this.frostiful$icicle = this.create(FDamageTypes.ICICLE);
    }

    @Override
    @Unique
    public class_1282 frostiful$fallingIcicle(class_1297 attacker) {
        return this.create(FDamageTypes.FALLING_ICICLE, attacker);
    }

    @Override
    @Unique
    public class_1282 frostiful$icicle() {
        return this.frostiful$icicle;
    }

    @Override
    @Unique
    public class_1282 frostiful$iceSkate(class_1297 attacker) {
        return this.create(FDamageTypes.ICE_SKATE, attacker);
    }

    @Override
    @Unique
    public class_1282 frostiful$brokenIce(class_1297 attacker) {
        return this.create(FDamageTypes.BROKEN_ICE, attacker);
    }
}
